<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package enpix
 */

get_header();
$opt      = get_option( 'enpix_opt' );
$opt_page = get_post_meta( get_queried_object_id(), 'page_options', true );

$blog_layout     = $opt['blog_layout'] ?? 'list';
$hide_page_title = $opt_page['hide_page_title'] ?? false;
$page_subtitle   = $opt_page['page_subtitle'] ?? '';
$is_sidebar      = $opt['is_blog_sidebar'] ?? true;

$blog_column = is_active_sidebar( 'sidebar_widgets' ) && $is_sidebar ? 'col-lg-8' : ( $blog_layout == 'list' ? 'col-lg-8 offset-lg-2' : 'col-lg-12' );

?>

	<main class="enpix-bg-1">
		<div class="container">
			<?php if ( ! $hide_page_title ) : ?>
				<div class="page-header pt-120 pb-80 text-center">
					<h1 class="mb-30"><?php echo esc_html( get_the_title( get_queried_object_id() ) ); ?></h1>
					<?php
					if ( ! empty( $page_subtitle ) ) {
						echo '<p class="enpix-subtitle-2">' . wp_kses( $page_subtitle, [ 'br' => [] ] ) . '</p>';
					}
					?>
				</div>
			<?php endif; ?>

			<div class="row">
				<div class="<?php echo esc_attr( $blog_column ); ?>">
					<div class="blog-<?php echo esc_attr( $blog_layout ); ?> pb-80">
						<?php
						// Sticky post
						while ( have_posts() ) :
							the_post();
							if ( is_sticky() ) :
								if ( is_active_sidebar( 'sidebar_widgets' ) && $is_sidebar ) {
									get_template_part( 'template-parts/blog/' . $blog_layout . '/content' );
								} else {
									get_template_part( 'template-parts/blog/' . $blog_layout . '/content', 'sticky' );
								}
							endif;
						endwhile;

						// Posts list
						while ( have_posts() ) :
							the_post();
							if ( ! is_sticky() ) :
								get_template_part( 'template-parts/blog/' . $blog_layout . '/content', get_post_format() );
							endif;

						endwhile;
						?>
					</div>

					<div class="enpix-pagination">
						<?php
						the_posts_pagination(
							[
								'prev_text' => '<i class="fa-solid fa-arrow-left-long"></i>',
								'next_text' => '<i class="fa-solid fa-arrow-right-long"></i>',
								'type'      => 'list',
							]
						);
						?>
					</div>
				</div>
				
				<?php
				if ( $is_sidebar ) {
					get_sidebar();
				}
				?>
			</div>

		</div>
	</main>

<?php
get_footer();
