<?php
/**
 * The template for displaying search results pages.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#search-result
 *
 * @package enpix
 */

get_header();

$opt = get_option( 'enpix_opt' );

$search_layout     = $opt['search_layout'] ?? 'grid';
$is_search_title   = $opt['is_search_title'] ?? true;
$search_title      = $opt['search_title'] ?? '';
$is_search_sidebar = $opt['is_search_sidebar'] ?? true;
$blog_column_grid  = is_active_sidebar( 'sidebar_widgets' ) && $is_search_sidebar ? 'col-lg-8 sidebar-enabled' : '';
$blog_column_list  = is_active_sidebar( 'sidebar_widgets' ) && $is_search_sidebar ? 'col-lg-8' : 'col-lg-8 offset-lg-2';
$blog_column       = $search_layout == 'list' ? $blog_column_list : $blog_column_grid;
?>
	<main class="enpix-bg-1">
		<div class="container">
			<div class="page-header pt-120 pb-80 text-center">
				<?php
				if ( $is_search_title ) {
					echo '<h1 class="mb-30">' . esc_html( $search_title ) . ' ' . esc_html( get_search_query() ) . '</h1>';
				}
				?>
			</div>


			<div class="row pb-80">
				<div class="<?php echo esc_attr( $blog_column ); ?>">
					<?php if ( $search_layout == 'list' ) : ?>
						<div class="blog-list pb-80">
							<?php
							// Posts list.
							while ( have_posts() ) :
								the_post();
								get_template_part( 'template-parts/blog/list/content', get_post_format() );
							endwhile;
							?>

							<div class="enpix-pagination">
								<?php
								the_posts_pagination(
									[
										'prev_text' => '<i class="fa-solid fa-arrow-left-long"></i>',
										'next_text' => '<i class="fa-solid fa-arrow-right-long"></i>',
										'type'      => 'list',
									]
								);
								?>
							</div>
						</div>
					<?php elseif ( $search_layout == 'grid' ) : ?>
						<div class="blog-grid">
							<?php
							// Posts grid
							while ( have_posts() ) :
								the_post();
								get_template_part( 'template-parts/blog/grid/content', get_post_format() );
							endwhile;
							?>

							<div class="enpix-pagination">
								<?php
								the_posts_pagination(
									[
										'prev_text' => '<i class="fa-solid fa-arrow-left-long"></i>',
										'next_text' => '<i class="fa-solid fa-arrow-right-long"></i>',
										'type'      => 'list',
									]
								);
								?>
							</div>
						</div>
					<?php endif; ?>
				</div>
				<?php
				if ( $is_search_sidebar ) {
					get_sidebar( 'sidebar_widgets' );
				}
				?>
			</div>
		</div>
	</main>

<?php
get_footer();
